/*******************************************************************************

Author : Mauro Laurenti
Version : 1.2
Created on Date : 23/09/2015
Last update     : 25/06/2016

CopyRight 2006-2016 all rights are reserved

********************************************************
SOFTWARE LICENSE AGREEMENT
********************************************************

The usage of the supplied software imply the acceptance of the following license.

The software supplied herewith by Mauro Laurenti (the Author) is intended for
use solely and exclusively on Microchip PIC Microcontroller (registered mark).
The software is owned by the Author, and is protected under applicable
copyright laws. All rights are reserved.
Any use in violation of the foregoing restrictions may subject the
user to criminal sanctions under applicable laws, as well as to civil liability
for the breach of the terms and conditions of this license.
Commercial use is forbidden without a written acknowledgment with the Author.
Personal or educational use is allowed if the application containing the
following software doesn't aim to commercial use or monetary earning of any kind.

THIS SOFTWARE IS PROVIDED IN AN "AS IS" CONDITION. NO WARRANTIES,
WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED
TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE AUTHOR SHALL NOT,
IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR
CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.

*******************************************************************************/

#include <xc.h>
#include <LTlib.h>

#include <LTlib_delay.h>
#include <LTlib_delay.c>

#include <module_IO.h>
#include <module_IO.c>

#define I2C_BIT_RATE 100
#include <module_UART.h>
#include <module_UART.c>

#include <module_I2C.h>
#include <module_I2C.c>

#include <module_ADC.h>
#include <module_ADC.c>

#include <MCP7940.h>
#include <MCP7940.c>

#include <MCP2300x.h>
#include <MCP2300x.c>

#include <LCD_44780_I2C.h>
#include <LCD_44780_I2C.c>

#include <I2C_EEPROM.h>
#include <I2C_EEPROM.c>

#include "buzzer_test.h"
#include "buzzer_test.c"

#include "led_string_test.h"
#include "led_string_test.c"

#include "LCD_test.h"
#include "LCD_test.c"

#include "EEPROM_test.h"
#include "EEPROM_test.c"

#include "buttons_test.h"
#include "buttons_test.c"

#include "analog_test.h"
#include "analog_test.c"

#include "UART_test.h"
#include "UART_test.c"

#include "RTC_test.h"
#include "RTC_test.c"

void board_initialization (void);

int main (void){

	unsigned char number_of_failures = 0;
    unsigned char counter = 0;

    IO_set_all_ports_as_inputs();
    IO_set_port_direction(IO_PORTD, IO_ALL_PORT_OUTPUT);
    IO_set_port_direction(IO_PORTC, IO_BIT0_OUT);

	beep_test ();

	led_test ();

    LCD_initialize(20);
	LCD_backlight_test ();
	LCD_hello_test ();

	number_of_failures += eeprom_test ();

	number_of_failures += RTC_test ();

	number_of_failures += UART_test ();
    number_of_failures += RS485_test ();
	
	analog_trimmer_test ();

	analog_light_test ();

	analog_temp_test ();

	button_test ();

	// Write Results
	delay_ms (1000);

	LCD_clear ();

	if (number_of_failures > 0)
		LCD_write_message ("SYSTEM TEST FAIL");
	else
		LCD_write_message ("SYSTEM TEST PASS");

    //********************************
    //max current setup
    //********************************   
    
    //Turn ON all the LEDs
    IO_set_port_direction(IO_PORTD, IO_ALL_PORT_OUTPUT);
    IO_write_port(IO_PORTD, 0xFF);
    
    //Write on the LCD
    LCD_backlight(LCD_TURN_ON_LED);
    LCD_goto_line(2);    
    LCD_write_message("  Counter : ");
    
    UART1_open(UART_BAUDRATE_115200);
    UART2_open(UART_BAUDRATE_115200);
    
    
 	while(1){	
        
        counter++;
        
        if (counter > 99) {
            counter = 0;
        }
        
        //USB data
        UART1_write_message("Hello ");
        
        //RS485 Data
        UART2_write_byte('A');
             
        LCD_goto_xy(13,2);        
        LCD_write_integer(counter,2,LCD_ZERO_CLEANING_OFF); 		
	}
}
